@@ -1,8 +1,8 @@
 use v6;
-use PDF::Annot;
+use PDF::Annot::Markup;
 
 class PDF::Annot::FileAttachment
-    is PDF::Annot {
+    is PDF::Annot::Markup {
 
     use PDF::COS::Tie;
     use PDF::COS::Name;
