@@ -9,7 +9,7 @@ class PDF::Annot::Widget
     use PDF::COS::Name;
 
     # See [PDF 1.7 TABLE 8.39 Additional entries specific to a widget annotation]
-    subset HName of PDF::COS::Name where 'N'|'I'|'O'|'P'|'T';
+    my subset HName of PDF::COS::Name where 'N'|'I'|'O'|'P'|'T';
     has HName $.H is entry(:alias<highlight-mode>);            #| (Optional; PDF 1.2) The annotation’s highlighting mode, the visual effect to be used when the mouse button is pressed or held down inside its active area:
                                        #| N(None)    - No highlighting.
                                        #| I(Invert)  - Invert the contents of the annotation rectangle.
