@@ -3,7 +3,7 @@ use v6;
 use PDF:ver(v0.3.2+);
 
 #| PDF entry-point. either a trailer dict or an XRef stream
-class PDF::Class:ver<0.2.3> #:api<PDF-1.7>
+class PDF::Class:ver<0.2.4> #:api<PDF-1.7>
     is PDF {
 
     # base class declares: $.Size, $.Encrypt, $.ID
@@ -34,15 +34,7 @@ class PDF::Class:ver<0.2.3> #:api<PDF-1.7>
 	$doc;
     }
 
-    method !preservation-needed {
-        if self.reader and my $sig-flags = self.Root.?AcroForm.?SigFlags {
-            constant AppendOnly = 2;
-	    return $sig-flags.flag-is-set: AppendOnly
-        }
-        False;
-    }
-
-    method save-as($spec, Bool :$info = True, Bool :$preserve = self!preservation-needed, |c) {
+    method save-as($spec, Bool :$info = True, |c) {
 
         if $info {
             my $now = DateTime.now;
@@ -57,7 +49,7 @@ class PDF::Class:ver<0.2.3> #:api<PDF-1.7>
                 $Info.CreationDate //= $now
             }
         }
-	nextwith($spec, :!info, :$preserve, |c);
+	nextwith($spec, :!info, |c);
     }
 
     method update(Bool :$info = True, |c) {
@@ -70,6 +62,18 @@ class PDF::Class:ver<0.2.3> #:api<PDF-1.7>
         nextsame;
     }
 
+    # permissions check, e.g: $doc.permitted( PermissionsFlag::Modify )
+    method permitted(UInt $flag --> Bool) {
+
+	my $perms = self.Encrypt.?P
+	    // return True;
+
+	return True
+	    if $.crypt.?is-owner;
+
+	return $perms.flag-is-set( $flag );
+    }
+
     method cb-init {
         unless self<Root> {
 	    self<Root> = { :Type( :name<Catalog> ) };
