@@ -29,10 +29,17 @@ PDF::COS.loader = class PDF::Class::Loader
 
     multi method load-delegate( Hash :$dict! where {.<Type>:exists}, :$base-class!) {
         my $type = from-ast($dict<Type>);
-        my $subtype = from-ast($dict<Subtype> // $dict<S>);
-        $type ~~ 'Ind'|'Ttl'|'Org'  # handled by PDF::OCG User attribute
-            |'OutputIntent' # no specific subclasses
-            |'Sig' # ref PDF::Signature
+        my $subtype = from-ast($_)
+            with $dict<Subtype> // $dict<S>;
+        with $subtype {
+            when '3D'   { $_ = 'ThreeD' }
+            when .chars <= 2
+            || $type ~~ 'OutputIntent' # no specific subclasses
+                        { $_ = Nil }
+        }
+        $type ~~
+            'Ind'|'Ttl'|'Org'  # handled by PDF::OCG
+            |'Sig'             # handled by PDF::Signature
             ?? $base-class
             !! $.find-delegate( $type, $subtype, :$base-class );
     }
@@ -44,10 +51,11 @@ PDF::COS.loader = class PDF::Class::Loader
 	my $type = do given $subtype {
 	    # See [PDF 1.7 - TABLE 8.20 Annotation types]
 	    when 'Text'|'Link'|'FreeText'|'Line'|'Square'|'Circle'
-		|'Polygon'|'PolyLine'|'Highlight' |' Underline'|'Squiggly'
+		|'Polygon'|'PolyLine'|'Highlight'|'Underline'|'Squiggly'
 		|'StrikeOut'|'Stamp'|'Caret'|'Ink'|'Popup'|'FileAttachment'
 		|'Sound'|'Movie'|'Widget'|'Screen'|'PrinterMark'|'TrapNet'
-		|'Watermark'|'3D'    { 'Annot' }
+		|'Watermark'    { 'Annot' }
+            when '3D' { $subtype = 'ThreeD'; 'Annot' }
 	    when 'PS'|'Image'|'Form' { 'XObject' }
             when 'Type1C'|'CIDFontType0C'|'OpenType' {
                 $subtype = Nil; # not currently subclassed
